@@ -30,4 +30,16 @@ class ServiceProxy(object):
     def __str__(self):
         self.__setupInstance()
         
-        return str(self._instance)
\ No newline at end of file
+        return str(self._instance)
+    
+    def __call__(self, *args, **kwargs):
+        self.__setupInstance()
+        
+        return self._instance(*args, **kwargs)
+    
+    def __repr__(self):
+        self.__setupInstance()
+        
+        return repr(self._instance)
+    
+        
\ No newline at end of file
